==> openmsghard-2.0.tar.gz: openmsghard-2.0/lib_util.c <==
//-----------------------------------------------------------
// Program  : ¸޽ϵ on NATEON
// Filename : lib_util.c
// Author   : ȣ
// Modify   : 08.02.26
// Comment  : ߱   Լ 
//-----------------------------------------------------------

#include "common.h"


//-----------------------------------------------------------
// Author   : ȣ
// Modify   : 08.02.26
// Comment  :  Ÿ Ǿ .
//-----------------------------------------------------------
void send_buf(int sock,char *buf) {
	//msg("send_buf()\n");
	//msg("****send buff****send len : %d********\n%s\n************************************\n",strlen(buf),buf);
    if(send(sock,buf,strlen(buf),0)==-1)
    	err(stderr,"%s , %s :: send error!!\n",__FILE__,__FUNCTION__);

}

//-----------------------------------------------------------
// Author   : ȣ
// Modify   : 08.02.26
// Comment  : Ͽ Ÿ .
//-----------------------------------------------------------
int recv_buf(int ds_sock,char *buf, int buf_size,int type) {

	int recv_len = -1;

	recv_len = recv(ds_sock,buf,buf_size-1,type);

	//if(recv_len == -1)
	//	assert("recv() error\n");

	//msg("----recv buff-----recv len : %d------\n%s\n-------------------------------------\n",recv_len,buf);

	return recv_len;

}

//-----------------------------------------------------------
// Author   : ȣ
// Modify   : 08.02.26
// Comment  : md5 ȣȭ
//-----------------------------------------------------------
void encrypt_md5(char *str, char *str_md5) {
	unsigned char md5_buf[34];
	unsigned char tmp_mdbuf[34];
	unsigned char md_buf[34];
	int i;
	snprintf(tmp_mdbuf,33,"%s",str);
	tmp_mdbuf[strlen(tmp_mdbuf)]='\0';
	MD5(tmp_mdbuf,strlen(tmp_mdbuf),md_buf);

	for(i=0; i<16; i++) {
        snprintf(&md5_buf[i*2],strlen(md_buf),"%02x",md_buf[i]);
    }
	strncpy(str_md5,md5_buf,strlen(md5_buf));

}
void make_dir(char *tmp_present_path, char *tmp_dir_name) {
	msg("make_dir\n");
	char present_path[strlen(tmp_present_path)+256];
	char make_path[MAX_BUF];
	char dir_name[256];

	char *dir_tok[2];
	memset(present_path, 0x0, sizeof(present_path));
	memset(dir_name, 0x0, 256);
	memset(dir_tok, 0x0, sizeof(dir_tok));
	memset(make_path, 0x0, MAX_BUF);
	strncpy(dir_name, tmp_dir_name, strlen(tmp_dir_name));
	strncpy(present_path, tmp_present_path, strlen(tmp_present_path));

	dir_tok[0] = strtok(dir_name, " ");
	dir_tok[1] = strtok(NULL,"\0");
	//printf("dir_name : %s\n",dir_name);
	//printf("dir_name : %s\n",dir_tok[0]);
	//printf("dir_name : %s\n",dir_tok[1]);


	snprintf(make_path, MAX_BUF, "%s/%s", present_path, dir_tok[1]);
	//printf("make_path : %s\n",make_path);

	//db_insert_dir(&conn,user_id,dir_tok[1],present_path);

	mkdir(make_path, 0700);

}


void remove_dir(list_file *head, char *present_path, char *tmp_remove) {
	char *remove_tok[12];
	char remove[256];
	char remove_path[MAX_PATH];
	list_file *p=NULL;
	memset(remove_path, 0x0, MAX_PATH);
	memset(remove, 0x0, sizeof(remove));
	memset(remove_tok, 0x0, sizeof(remove_tok));

	strncpy(remove, tmp_remove, strlen(tmp_remove));

	int i;
	string_strtok(remove, remove_tok," ");

	for (i=1; remove_tok[i]; i++) {

		p=head;
		while (p=p->Next) {
			if (p->data.list_num ==atoi(remove_tok[i]) && atoi(remove_tok[i])!=0) {

				snprintf(remove_path, MAX_PATH, "\"%s/%s\"", present_path,p->data.filename);

				char excute_buf[strlen(remove_path)+8];

				memset(excute_buf, 0x0, sizeof(excute_buf));

				snprintf(excute_buf, sizeof(excute_buf), "rm -rf %s",remove_path);
				//printf("before execute %s\n",excute_buf);
				system(excute_buf);
				//printf("after execute\n");

			}

		}

	}

}


void make_share_folder() {


	char make_path[MAX_BUF];


	//printf("dir_name : %s\n",dir_name);
	//printf("dir_name : %s\n",dir_tok[0]);
	//printf("dir_name : %s\n",dir_tok[1]);


	snprintf(make_path, MAX_BUF, "ln -s %s/%s %s/shares/", conf.default_home, conf.client_id,conf.default_home);
	//printf("make_path : %s\n",make_path);

	//db_insert_dir(&conn,user_id,dir_tok[1],present_path);

	system(make_path);

}
void remove_share_folder() {


	char remove_path[MAX_BUF];


	//printf("dir_name : %s\n",dir_name);
	//printf("dir_name : %s\n",dir_tok[0]);
	//printf("dir_name : %s\n",dir_tok[1]);


	snprintf(remove_path, MAX_BUF, "rm -rf %s/shares/%s", conf.default_home, conf.client_id);
	//printf("make_path : %s\n",make_path);

	//db_insert_dir(&conn,user_id,dir_tok[1],present_path);

	system(remove_path);

}


void z_handler(int sig) {
	pid_t pid;
	int rtn;
	while((pid=waitpid(-1,&rtn,WNOHANG))>0) {

		//printf("<<<child process %d exit..(%s) return %d\n",pid,conf.client_id,rtn);
	}
}

void create_home(char *username) {
	printf("start create_home()\n");
	char create_home[strlen(conf.default_home) + strlen(username)+3];

	snprintf(create_home,sizeof(create_home),"%s/%s",conf.default_home,username);

	//printf("home : %s\n",create_home);
	mkdir(create_home,0700);
}

//-----------------------------------------------------------
// Author   : ȣ
// Modify   : 08.06.14
// Comment  : μ ȭ.
//-----------------------------------------------------------
void daemonize() {
	int i;
	printf("Daemon started..\n");
	if (fork() != 0)
		exit(0);
	setsid();
	signal(SIGHUP, SIG_IGN);
	if (fork() != 0)
	exit(0);
	chdir("/");
	umask(0);

}

==> openmsghard-2.1.tar.gz: openmsghard-2.1/lib_util.c <==
//-----------------------------------------------------------
// Program  : ¸޽ϵ on NATEON
// Filename : lib_util.c
// Author   : ȣ
// Modify   : 08.02.26
// Comment  : ߱   Լ 
//-----------------------------------------------------------

#include "common.h"


//-----------------------------------------------------------
// Author   : ȣ
// Modify   : 08.02.26
// Comment  :  Ÿ Ǿ .
//-----------------------------------------------------------
void send_buf(int sock,char *buf) {
	//msg("send_buf()\n");
	//msg("****send buff****send len : %d********\n%s\n************************************\n",strlen(buf),buf);
    if(send(sock,buf,strlen(buf),0)==-1)
    	err(stderr,"%s , %s :: send error!!\n",__FILE__,__FUNCTION__);

}

//-----------------------------------------------------------
// Author   : ȣ
// Modify   : 08.02.26
// Comment  : Ͽ Ÿ .
//-----------------------------------------------------------
int recv_buf(int ds_sock,char *buf, int buf_size,int type) {

	int recv_len = -1;

	recv_len = recv(ds_sock,buf,buf_size-1,type);

	//if(recv_len == -1)
	//	assert("recv() error\n");

	//msg("----recv buff-----recv len : %d------\n%s\n-------------------------------------\n",recv_len,buf);

	return recv_len;

}

//-----------------------------------------------------------
// Author   : ȣ
// Modify   : 08.02.26
// Comment  : md5 ȣȭ
//-----------------------------------------------------------
void encrypt_md5(char *str, char *str_md5) {
	unsigned char md5_buf[34];
	unsigned char tmp_mdbuf[34];
	unsigned char md_buf[34];
	int i;
	snprintf(tmp_mdbuf,33,"%s",str);
	tmp_mdbuf[strlen(tmp_mdbuf)]='\0';
	MD5(tmp_mdbuf,strlen(tmp_mdbuf),md_buf);

	for(i=0; i<16; i++) {
        snprintf(&md5_buf[i*2],strlen(md_buf),"%02x",md_buf[i]);
    }
	strncpy(str_md5,md5_buf,strlen(md5_buf));

}
void make_dir(char *tmp_present_path, char *tmp_dir_name) {
	msg("make_dir\n");
	char present_path[strlen(tmp_present_path)+256];
	char make_path[MAX_BUF];
	char dir_name[256];

	char *dir_tok[2];
	memset(present_path, 0x0, sizeof(present_path));
	memset(dir_name, 0x0, 256);
	memset(dir_tok, 0x0, sizeof(dir_tok));
	memset(make_path, 0x0, MAX_BUF);
	strncpy(dir_name, tmp_dir_name, strlen(tmp_dir_name));
	strncpy(present_path, tmp_present_path, strlen(tmp_present_path));

	dir_tok[0] = strtok(dir_name, " ");
	dir_tok[1] = strtok(NULL,"\0");
	//printf("dir_name : %s\n",dir_name);
	//printf("dir_name : %s\n",dir_tok[0]);
	//printf("dir_name : %s\n",dir_tok[1]);


	snprintf(make_path, MAX_BUF, "%s/%s", present_path, dir_tok[1]);
	//printf("make_path : %s\n",make_path);

	//db_insert_dir(&conn,user_id,dir_tok[1],present_path);

	mkdir(make_path, 0700);

}


void remove_dir(list_file *head, char *present_path, char *tmp_remove) {
	char *remove_tok[12];
	char remove[256];
	char remove_path[MAX_PATH];
	list_file *p=NULL;
	memset(remove_path, 0x0, MAX_PATH);
	memset(remove, 0x0, sizeof(remove));
	memset(remove_tok, 0x0, sizeof(remove_tok));

	strncpy(remove, tmp_remove, strlen(tmp_remove));

	int i;
	string_strtok(remove, remove_tok," ");

	for (i=1; remove_tok[i]; i++) {

		p=head;
		while (p=p->Next) {
			if (p->data.list_num ==atoi(remove_tok[i]) && atoi(remove_tok[i])!=0) {

				snprintf(remove_path, MAX_PATH, "\"%s/%s\"", present_path,p->data.filename);

				char excute_buf[strlen(remove_path)+8];

				memset(excute_buf, 0x0, sizeof(excute_buf));

				snprintf(excute_buf, sizeof(excute_buf), "rm -rf %s",remove_path);
				//printf("before execute %s\n",excute_buf);
				system(excute_buf);
				//printf("after execute\n");

			}

		}

	}

}


void make_share_folder() {


	char make_path[MAX_BUF];


	//printf("dir_name : %s\n",dir_name);
	//printf("dir_name : %s\n",dir_tok[0]);
	//printf("dir_name : %s\n",dir_tok[1]);


	snprintf(make_path, MAX_BUF, "ln -s %s/%s %s/shares/", conf.default_home, conf.client_id,conf.default_home);
	//printf("make_path : %s\n",make_path);

	//db_insert_dir(&conn,user_id,dir_tok[1],present_path);

	system(make_path);

}
void remove_share_folder() {


	char remove_path[MAX_BUF];


	//printf("dir_name : %s\n",dir_name);
	//printf("dir_name : %s\n",dir_tok[0]);
	//printf("dir_name : %s\n",dir_tok[1]);


	snprintf(remove_path, MAX_BUF, "rm -rf %s/shares/%s", conf.default_home, conf.client_id);
	//printf("make_path : %s\n",make_path);

	//db_insert_dir(&conn,user_id,dir_tok[1],present_path);

	system(remove_path);

}


void z_handler(int sig) {
	pid_t pid;
	int rtn;
	while((pid=waitpid(-1,&rtn,WNOHANG))>0) {

		fmsg("<<<child process %d exit..(%s) return %d\n",pid,conf.client_id,rtn);
	}
}

void create_home(char *username) {
	//printf("start create_home()\n");
	char create_home[strlen(conf.default_home) + strlen(username)+3];

	snprintf(create_home,sizeof(create_home),"%s/%s",conf.default_home,username);

	fmsg("join : %s\n",create_home);
	mkdir(create_home,0700);
}

//-----------------------------------------------------------
// Author   : ȣ
// Modify   : 08.06.14
// Comment  : μ ȭ.
//-----------------------------------------------------------
void daemonize() {
	int i;
	printf("Daemon started..\n");
	if (fork() != 0)
		exit(0);
	setsid();
	signal(SIGHUP, SIG_IGN);
	if (fork() != 0)
	exit(0);
	chdir("/");
	umask(0);

}
